@@ -1,7 +1,7 @@
 """DB-SIG compliant module for communicating with MS SQL servers"""
 
 __author__ = 'Mikhail Denisenko <denisenkom@gmail.com>'
-__version__ = '1.5.1'
+__version__ = '1.5.2'
 
 import logging
 import six
@@ -232,7 +232,8 @@ class _Connection(object):
         except socket.error as e:
             if e.errno == errno.ECONNRESET:
                 return
-            logger.exception('unexpected error in rollback')
+        except ClosedConnectionError:
+            pass
         except:
             logger.exception('unexpected error in rollback')
 
@@ -348,7 +349,8 @@ class _Connection(object):
             elif result_type == TDS_STATUS_RESULT:
                 continue
             else:
-                logger.error('logic error: tds_process_tokens result_type %d', result_type)
+                raise Exception('Invalid result type: ' + str(result_type))
+
 
     def _fetchone(self, cursor):
         """
@@ -363,7 +365,11 @@ class _Connection(object):
         if self._state == DB_RES_NO_MORE_RESULTS:
             return None
 
-        self._nextrow(session)
+        try:
+            self._nextrow(session)
+        except:
+            session.close()
+            raise
 
         if self._state != DB_RES_RESULTSET_ROWS:
             return None
@@ -566,7 +572,20 @@ class _Cursor(six.Iterator):
 
     def _open(self):
         if self._conn._conn.mars_enabled:
-            self._session = self._conn._conn.create_session()
+            in_tran = self._conn._conn.tds72_transaction
+            if in_tran and self._conn._dirty:
+                self._session = self._conn._conn.create_session()
+            else:
+                try:
+                    self._session = self._conn._conn.create_session()
+                    return
+                except socket.error as e:
+                    if e.errno != errno.ECONNRESET:
+                        raise
+                except ClosedConnectionError:
+                    pass
+                self._conn._assert_open()
+                self._session = self._conn._conn.create_session()
         else:
             self._session = self._conn._conn.main_session
 
@@ -606,6 +625,14 @@ class _Cursor(six.Iterator):
     def connection(self):
         return self._conn
 
+    @property
+    def spid(self):
+        # not thread safe for connection
+        dirty = self._conn._dirty
+        spid = self.execute_scalar('select @@SPID')
+        self._conn._dirty = dirty
+        return spid
+
     def get_proc_return_status(self):
         return self._conn._get_proc_return_status(self)
 
@@ -758,7 +785,6 @@ def connect(server='.', database='', user='', password='', timeout=0,
     :keyword port: the TCP port to use to connect to the server
     :type appname: string
     """
-
     # set the login timeout
     try:
         login_timeout = int(login_timeout)
