@@ -30,7 +30,7 @@ def tds_start_query(tds):
         assert len(tds.conn.tds72_transaction) == 8
         w.write(tds.conn.tds72_transaction)
     else:
-        w.write('\x00\x00\x00\x00\x00\x00\x00\x00')
+        w.write(b'\x00\x00\x00\x00\x00\x00\x00\x00')
     w.put_uint(1)  # request count
 
 
@@ -46,12 +46,7 @@ def convert_params(tds, parameters):
     else:
         params = []
         for parameter in parameters:
-            if type(parameter) is output:
-                raise NotImplementedError
-                #param_type = parameter.type
-                #param_value = parameter.value
-                #param_output = True
-            elif isinstance(parameter, _Column):
+            if isinstance(parameter, _Column):
                 params.append(parameter)
             else:
                 params.append(make_param(tds, '', parameter))
@@ -204,7 +199,6 @@ def tds_send_cancel(tds):
 # \return TDS_SUCCESS or TDS_FAIL
 #
 def tds_put_data_info(tds, curcol):
-    logger.debug("tds_put_data_info putting param_name")
     w = tds._writer
     if IS_TDS7_PLUS(tds):
         w.put_byte(len(curcol.column_name))
@@ -219,7 +213,6 @@ def tds_put_data_info(tds, curcol):
     # (what's the meaning of "default value" ?)
     #
 
-    logger.debug("tds_put_data_info putting status")
     w.put_byte(curcol.flags)
     if not IS_TDS7_PLUS(tds):
         w.put_int(curcol.column_usertype)  # usertype
