@@ -243,6 +243,11 @@ class DatabaseError(Error):
                 self.state, self.line, self.text)
 
 
+class ClosedConnectionError(InterfaceError):
+    def __init__(self):
+        super(ClosedConnectionError, self).__init__('Server closed connection')
+
+
 class DataError(Error):
     pass
 
@@ -421,12 +426,12 @@ def skipall(stm, size):
     if len(res) == size:
         return
     elif len(res) == 0:
-        raise Error('Server closed connection')
+        raise ClosedConnectionError()
     left = size - len(res)
     while left:
         buf = stm.read(left)
         if len(buf) == 0:
-            raise Error('Server closed connection')
+            raise ClosedConnectionError()
         left -= len(buf)
 
 
@@ -435,13 +440,13 @@ def readall(stm, size):
     if len(res) == size:
         return res
     elif len(res) == 0:
-        raise Error('Server closed connection')
+        raise ClosedConnectionError()
     chunks = [res]
     left = size - len(res)
     while left:
         buf = stm.read(left)
         if len(buf) == 0:
-            raise Error('Server closed connection')
+            raise ClosedConnectionError()
         chunks.append(buf)
         left -= len(buf)
     return b''.join(chunks)
@@ -896,7 +901,7 @@ class _TdsSocket(object):
         try:
             buf = self._sock.recv(size)
             if len(buf) == 0:
-                raise Error('Server closed connection')
+                raise ClosedConnectionError()
             return buf
         except TimeoutError:
             raise
